IronCalc
========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage_examples
   top_level_methods
   raw_api_reference
   user_api_reference
   objects

IronCalc is a spreadsheet engine that allows you to create, modify and save spreadsheets.

A simple example that creates a model, sets a formula, evaluates it and gets the result back:

.. literalinclude:: examples/simple.py
   :language: python

